import * as PropTypes from 'prop-types';
import * as uuid from 'uuid/v1';
export const contextTypes = {
    on: PropTypes.any,
    off: PropTypes.any,
    draggableClass: PropTypes.any,
};
export class DraggableContext {
    constructor() {
        this.queue = [];
        this.draggableClass = 'draggable' + uuid();
        this.on = this.on.bind(this);
        this.off = this.off.bind(this);
        this.flushQueue = this.flushQueue.bind(this);
        this.filter = this.filter.bind(this);
    }
    on(eventName, listener) {
        this.queue.push([eventName, listener]);
        if (this.draggable != null) {
            this.flushQueue();
        }
    }
    off(eventName, listener) {
        this.draggable.off(eventName, listener);
    }
    flushQueue() {
        let onEvent;
        while (onEvent = this.queue.pop()) {
            this.draggable.on(onEvent[0], onEvent[1]);
        }
    }
    filter() {
        return {
            on: this.on,
            off: this.off,
            draggableClass: this.draggableClass,
        };
    }
    destroy() {
        this.draggable.destroy();
        delete this.draggable;
    }
}
